"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ts = require("typescript");
const vscode_jsonrpc_1 = require("vscode-jsonrpc");
exports.CancellationToken = vscode_jsonrpc_1.CancellationToken;
exports.CancellationTokenSource = vscode_jsonrpc_1.CancellationTokenSource;
/**
 * Thrown when an operation was cancelled
 */
class CancelledError extends Error {
    constructor(message = 'Operation cancelled') {
        super(message);
    }
}
exports.CancelledError = CancelledError;
/**
 * Returns true if the passed error was caused by a cancellation
 */
function isCancelledError(error) {
    return typeof error === 'object' && error !== null && (error instanceof CancelledError
        || error instanceof ts.OperationCanceledException
        || (typeof error.name === 'string' && error.name.includes('Cancel')));
}
exports.isCancelledError = isCancelledError;
/**
 * Throws a CancelledError if cancellation was requested for the passed CancellationToken
 */
function throwIfRequested(token) {
    if (token.isCancellationRequested) {
        throw new CancelledError();
    }
}
exports.throwIfRequested = throwIfRequested;
//# sourceMappingURL=cancellation.js.map