import { CancellationToken } from 'vscode-jsonrpc';
import { LanguageClientHandler } from './lang-handler';
export interface FileSystem {
    /**
     * Returns all files in the workspace under base
     *
     * @param base A URI under which to search, resolved relative to the rootUri
     * @return A promise that is fulfilled with an array of URIs
     */
    getWorkspaceFiles(base?: string, token?: CancellationToken): Promise<string[]>;
    /**
     * Returns the content of a text document
     *
     * @param uri The URI of the text document, resolved relative to the rootUri
     * @return A promise that is fulfilled with the text document content
     */
    getTextDocumentContent(uri: string, token?: CancellationToken): Promise<string>;
}
export declare class RemoteFileSystem implements FileSystem {
    private client;
    private workspaceFilesPromise?;
    constructor(client: LanguageClientHandler);
    /**
     * The files request is sent from the server to the client to request a list of all files in the workspace or inside the directory of the base parameter, if given.
     * A language server can use the result to index files by filtering and doing a content request for each text document of interest.
     */
    getWorkspaceFiles(base?: string, token?: CancellationToken): Promise<string[]>;
    /**
     * The content request is sent from the server to the client to request the current content of any text document. This allows language servers to operate without accessing the file system directly.
     */
    getTextDocumentContent(uri: string, token?: CancellationToken): Promise<string>;
}
export declare class LocalFileSystem implements FileSystem {
    private rootPath;
    /**
     * @param rootPath The root directory path that relative URIs should be resolved to
     */
    constructor(rootPath: string);
    /**
     * Converts the URI to an absolute path
     */
    protected resolveUriToPath(uri: string): string;
    getWorkspaceFiles(base?: string): Promise<string[]>;
    getTextDocumentContent(uri: string): Promise<string>;
}
