"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("mz/fs");
const path = require("path");
const vscode_jsonrpc_1 = require("vscode-jsonrpc");
const glob = require("glob");
const util_1 = require("./util");
class RemoteFileSystem {
    constructor(client) {
        this.client = client;
    }
    /**
     * The files request is sent from the server to the client to request a list of all files in the workspace or inside the directory of the base parameter, if given.
     * A language server can use the result to index files by filtering and doing a content request for each text document of interest.
     */
    getWorkspaceFiles(base, token = vscode_jsonrpc_1.CancellationToken.None) {
        // TODO cache this at a different layer and invalidate it properly
        // This is just a quick and dirty solution to avoid multiple requests
        if (!this.workspaceFilesPromise) {
            this.workspaceFilesPromise = this.client.getWorkspaceFiles({ base }, token)
                .then((textDocuments) => textDocuments.map(textDocument => textDocument.uri))
                .catch(err => {
                this.workspaceFilesPromise = undefined;
                throw err;
            });
        }
        return this.workspaceFilesPromise;
    }
    /**
     * The content request is sent from the server to the client to request the current content of any text document. This allows language servers to operate without accessing the file system directly.
     */
    getTextDocumentContent(uri, token = vscode_jsonrpc_1.CancellationToken.None) {
        return __awaiter(this, void 0, void 0, function* () {
            const textDocument = yield this.client.getTextDocumentContent({ textDocument: { uri } }, token);
            return textDocument.text;
        });
    }
}
exports.RemoteFileSystem = RemoteFileSystem;
class LocalFileSystem {
    /**
     * @param rootPath The root directory path that relative URIs should be resolved to
     */
    constructor(rootPath) {
        this.rootPath = rootPath;
    }
    /**
     * Converts the URI to an absolute path
     */
    resolveUriToPath(uri) {
        return path.resolve(this.rootPath, util_1.uri2path(uri));
    }
    getWorkspaceFiles(base) {
        return __awaiter(this, void 0, void 0, function* () {
            const files = yield new Promise((resolve, reject) => {
                glob(path.join(this.resolveUriToPath(base), '**/*.*'), { nodir: true }, (err, matches) => err ? reject(err) : resolve(matches));
            });
            return files.map(file => util_1.path2uri('', file));
        });
    }
    getTextDocumentContent(uri) {
        return __awaiter(this, void 0, void 0, function* () {
            return fs.readFile(this.resolveUriToPath(uri), 'utf8');
        });
    }
}
exports.LocalFileSystem = LocalFileSystem;
//# sourceMappingURL=fs.js.map