"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cluster = require("cluster");
const net = require("net");
const connection_1 = require("./connection");
function rewriteConsole() {
    return __awaiter(this, void 0, void 0, function* () {
        const consoleErr = console.error;
        console.error = function error() {
            if (cluster.isMaster) {
                consoleErr.call(this, `[mstr]`, ...arguments);
            }
            else {
                consoleErr.call(this, `[wkr${cluster.worker.id}]`, ...arguments);
            }
        };
    });
}
/**
 * serve starts a singleton language server instance that uses a
 * cluster of worker processes to achieve some semblance of
 * parallelism.
 */
function serve(options, createLangHandler) {
    return __awaiter(this, void 0, void 0, function* () {
        rewriteConsole();
        if (options.clusterSize > 1 && cluster.isMaster) {
            console.error(`Master (PID ${process.pid}) spawning ${options.clusterSize} workers`);
            cluster.on('online', worker => {
                console.error(`Worker ${worker.id} (PID ${worker.process.pid}) online`);
            });
            cluster.on('exit', (worker, code, signal) => {
                console.error(`Worker ${worker.id} (PID ${worker.process.pid}) exited from signal ${signal} with code ${code}, restarting`);
                cluster.fork();
            });
            for (let i = 0; i < options.clusterSize; ++i) {
                cluster.fork();
            }
        }
        else {
            console.error('Listening for incoming LSP connections on', options.lspPort);
            let counter = 1;
            let server = net.createServer(socket => {
                const id = counter++;
                console.error(`Connection ${id} accepted`);
                // This connection listens on the socket
                const connection = connection_1.newConnection(socket, socket, options);
                // Override the default exit notification handler so the process is not killed
                connection.onNotification('exit', () => {
                    socket.end();
                    socket.destroy();
                    console.error(`Connection ${id} closed (exit notification)`);
                });
                connection_1.registerLanguageHandler(connection, createLangHandler(connection));
                connection.listen();
            });
            server.listen(options.lspPort);
        }
    });
}
exports.serve = serve;
//# sourceMappingURL=server.js.map