import { TypeScriptService } from '../typescript-service';
export interface TestContext {
    /** TypeScript service under test */
    service: TypeScriptService;
}
/**
 * Returns a function that initializes the test context with a TypeScriptService instance and initializes it (to be used in `beforeEach`)
 *
 * @param TypeScriptServiceConstructor The TypeScriptService subclass to instantiate
 * @param files A Map from URI to file content of files that should be available in the workspace
 */
export declare const initializeTypeScriptService: (TypeScriptServiceConstructor: typeof TypeScriptService, files: Map<string, string>) => (this: TestContext) => Promise<void>;
/**
 * Shuts the TypeScriptService down (to be used in `afterEach()`)
 */
export declare function shutdownTypeScriptService(this: TestContext): Promise<void>;
/**
 * Describe a TypeScriptService class
 *
 * @param TypeScriptServiceConstructor The TypeScriptService subclass to describe
 */
export declare function describeTypeScriptService(TypeScriptServiceConstructor?: typeof TypeScriptService): void;
